@@ -84,9 +84,7 @@ options(
         extra_files=['virtual', 'svn', 'version']
     ),
     virtualenv=Bunch(
-        paver_command_line='develop',
-        unzip_setuptools=True,
-        distribute=True
+        paver_command_line='develop'
     ),
     # sphinxcontrib.paverutils
     sphinx=Bunch(
@@ -373,13 +371,3 @@ def pep8(args):
     styleguide = pep8.StyleGuide(show_source=True, ignore=ignore, repeat=1, max_line_length=120,
                                  parse_argv=args)
     styleguide.input_dir('flexget')
-
-
-@task
-def bootstrap():
-    vopts = options.virtualenv
-    paver.virtual._create_bootstrap(vopts.get("script_name", "bootstrap.py"),
-                                    vopts.get("packages_to_install", []),
-                                    vopts.get("paver_command_line", None),
-                                    dest_dir=vopts.get("dest_dir", '.'),
-                                    unzip_setuptools=vopts.get("unzip_setuptools", False))
